"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CypressCliUtils = void 0;
var test_results_1 = require("./test-results");
require("cypress");
var CypressCliUtils = /** @class */ (function () {
    function CypressCliUtils() {
    }
    CypressCliUtils.convertCypressRunResult = function (results, options) {
        var testRuns;
        if (!options.specMapping || options.specMapping === "cycle") {
            testRuns = this.convertSpecsToTestCycles(results, options);
        }
        else {
            testRuns = this.convertSpecsToTests(results, options);
        }
        return testRuns;
    };
    CypressCliUtils.convertSpecsToTests = function (results, options) {
        var _this = this;
        var testRun = new test_results_1.TestRun();
        var testCycleName = options.cycleName;
        testRun.name = testCycleName
            ? testCycleName
            : "Cypress Test Cycle";
        testRun.results = [];
        results.runs.forEach(function (r) {
            var testResult = new test_results_1.TestResult();
            testResult.name = r.tests[0].title[0];
            testResult.status = r.stats.tests === r.stats.passes
                ? "passed"
                : "failed";
            var _a = _this.extractStartedDateAndDurationForRunResult(r), startedAt = _a.startedAt, duration = _a.duration;
            testResult.startedAt = startedAt;
            testResult.duration = duration;
            testResult.comment = _this.extractErrorMessageForRunResult(r);
            testResult.environment = _this.extractEnvironmentVariable(results, options);
            testRun.results.push(testResult);
        });
        return [testRun];
    };
    CypressCliUtils.extractStartedDateAndDurationForRunResult = function (runResult) {
        var startedAt = new Date(runResult.stats.startedAt);
        var duration = runResult.stats.duration;
        return {
            startedAt: new Date(startedAt),
            duration: duration
        };
    };
    CypressCliUtils.extractErrorMessageForRunResult = function (runResult) {
        var failure = runResult.tests.find(function (t) { return t.displayError; });
        return failure ? failure.displayError : undefined;
    };
    CypressCliUtils.convertSpecsToTestCycles = function (results, options) {
        var _this = this;
        var testRuns = [];
        results.runs.forEach(function (r) {
            var testRun = new test_results_1.TestRun();
            testRun.name = r.tests[0].title[0];
            testRun.results = [];
            r.tests.forEach(function (tr) {
                var testResult = new test_results_1.TestResult();
                testResult.name = tr.title[1];
                testResult.status = tr.state;
                var _a = _this.extractStartedDateAndDurationForTestResult(tr), startedAt = _a.startedAt, duration = _a.duration;
                testResult.startedAt = startedAt;
                testResult.duration = duration;
                testResult.comment = _this.extractErrorMessageForTestResult(tr);
                testResult.environment = _this.extractEnvironmentVariable(results, options);
                testRun.results.push(testResult);
            });
            testRuns.push(testRun);
        });
        return testRuns;
    };
    CypressCliUtils.extractErrorMessageForTestResult = function (testResult) {
        return testResult.displayError;
    };
    CypressCliUtils.extractStartedDateAndDurationForTestResult = function (testResult) {
        var startedAt = testResult.attempts[0].startedAt;
        var duration = 0;
        testResult.attempts.forEach(function (a) {
            duration += a.duration;
        });
        return {
            startedAt: new Date(startedAt),
            duration: duration
        };
    };
    CypressCliUtils.extractEnvironmentVariable = function (results, options) {
        var envVariable = options.environmentProperty;
        if (envVariable) {
            return results.config.env[envVariable];
        }
        else {
            return undefined;
        }
    };
    return CypressCliUtils;
}());
exports.CypressCliUtils = CypressCliUtils;
//# sourceMappingURL=cypress-cli-utils.js.map